@@ -1,12 +1,13 @@
 #!/usr/bin/env python
 
-import sys, os, time
+import sys, time
 import whisper
 from optparse import OptionParser
 
 now = int( time.time() )
 
-option_parser = OptionParser(usage='''%prog [options] path timestamp:value [timestamp:value]*''')
+option_parser = OptionParser(
+    usage='''%prog [options] path timestamp:value [timestamp:value]*''')
 
 (options, args) = option_parser.parse_args()
 
@@ -16,7 +17,8 @@ if len(args) < 2:
 
 path = args[0]
 datapoint_strings = args[1:]
-datapoint_strings = [point.replace('N:', '%d:' % now) for point in datapoint_strings]
+datapoint_strings = [point.replace('N:', '%d:' % now)
+                     for point in datapoint_strings]
 datapoints = [tuple(point.split(':')) for point in datapoint_strings]
 
 if len(datapoints) == 1:
